// Persistence of Vision Ray Tracer Include File
// File: rchar.inc
// Vers: 3.1
// Desc: Rounded Characters
// Date: 25 May 2000
// Auth: Matthew Edd Tillman
//       e-mail: mrhorse@usa.net
//       www:    http://www.bigfoot.com/~special_edd

//       chacacter front is on z=-.1, text back is on z=.1

//-----Capped_Cylinder---------
#macro Capped_Cylinder (FlatEnd,RoundEnd,Radius)
  union {
    cylinder {FlatEnd,RoundEnd,Radius}
    sphere {RoundEnd,Radius}
    }
#end
//-----Rounded_Cylinder--------
#macro Rounded_Cylinder (EndPointA,EndPointB,Radius)
  union {
    sphere {EndPointA,Radius}
    Capped_Cylinder (EndPointA,EndPointB,Radius)
  }
#end
//-----Uncapped_Eighth_Circle_Rounded--------
#macro Uncapped_Eighth_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate)
  difference {
    torus {MainRadius,MinorRadius rotate <90,0,0>}
    box {<-MinorRadius-MainRadius-.1,-MinorRadius-MainRadius-.1,-MinorRadius-.1>,<0,MinorRadius+MainRadius+.1,MinorRadius+.1>}
    box {<-.1,-MinorRadius-MainRadius-.1,-MinorRadius-.1>,<MinorRadius+MainRadius+.1,0,MinorRadius+.1>}
    box {<-MinorRadius-MainRadius-.1,-MinorRadius-MainRadius-.1,-MinorRadius-.1>,<0,MinorRadius+MainRadius+.1,MinorRadius+.1> rotate <0,0,-45>}
    rotate <0,0,Rotate>
    translate Center  
  }    
#end

//-----Eighth_Circle_Rounded------------
#macro Eighth_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate)    
  union {
    Uncapped_Eighth_Circle_Rounded (0,MainRadius,MinorRadius,0)
    sphere {<MainRadius,0,0>,MinorRadius}
    sphere {<0,MainRadius,0>,MinorRadius rotate <0,0,-45>}
    rotate <0,0,Rotate>
    translate Center
  }
#end

//-----Quarter_Circle_Rounded---------
#macro Quarter_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate)
  union {
    sphere {<MainRadius,0,0>,MinorRadius}
    sphere {<0,MainRadius,0>,MinorRadius}
    difference {
       torus {MainRadius,MinorRadius rotate <90,0,0>}
       box {<-MinorRadius-MainRadius-.1,-MinorRadius-MainRadius-.1,-MinorRadius-.1>,<0,MinorRadius+MainRadius+.1,MinorRadius+.1>}
       box {<-.1,-MinorRadius-MainRadius-.1,-MinorRadius-.1>,<MinorRadius+MainRadius+.1,0,MinorRadius+.1>}
       
       }
     rotate <0,0,Rotate>
     translate Center
     }
#end
//-----Half_Circle_Rounded------------
#macro Half_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate)
  union {
    Quarter_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate)
    Quarter_Circle_Rounded (Center,MainRadius,MinorRadius,Rotate+90)
    }
#end
//-----Torus------------
#macro Torus (Center,MainRadius,MinorRadius)
  torus {MainRadius,MinorRadius rotate <90,0,0> translate Center}
#end
// ----- Rounded_A -----
#declare Rounded_A =
union {
  Rounded_Cylinder (<.1,.1,0>,<.5,1.4,0>,.1)
  Capped_Cylinder (<.5,1.4,0>,<.9,.1,0>,.1)
  cylinder {<.233,.5,0>,<.766,.5,0>,.1}
  }
  
// ----- Rounded_P -----
#declare Rounded_P = 
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  cylinder {<.1,.8,0>,<.5,.8,0>,.1}
  cylinder {<.1,1.4,0>,<.5,1.4,0>,.1}
  Half_Circle_Rounded (<.5,1.1,0>,.3,.1,-90)
  }

// ----- Rounded_B -----
#declare Rounded_B =
union {
  object {Rounded_P}
  Quarter_Circle_Rounded (<.5,.5,0>,.3,.1,0)
  Quarter_Circle_Rounded (<.5,.4,0>,.3,.1,-90)
  cylinder {<.1,.1,0>,<.5,.1,0>,.1}
  cylinder {<.8,.5,0>,<.8,.4,0>,.1}
  }

// ----- Rounded_C -----
#declare Rounded_C =
union {
  Half_Circle_Rounded (<.5,1,0>,.4,.1,0)
  Half_Circle_Rounded (<.5,.5,0>,.4,.1,180)
  cylinder {<.1,.5,0>,<.1,1,0>,.1}
  }

// ----- Rounded_D -----
#declare Rounded_D =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  cylinder {<.1,.1,0>,<.4,.1,0>,.1}
  cylinder {<.1,1.4,0>,<.4,1.4,0>,.1}
  Quarter_Circle_Rounded (<.4,1,0>,.4,.1,0)
  Quarter_Circle_Rounded (<.4,.5,0>,.4,.1,-90)
  cylinder {<.8,.5,0>,<.8,1,0>,.1}
  }
   
// ----- Rounded_F -----
#declare Rounded_F =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Capped_Cylinder (<.1,1.4,0>,<.8,1.4,0>,.1)
  Capped_Cylinder (<.1,.8,0>,<.8,.8,0>,.1)
  }
  
// ----- Rounded_E -----
#declare Rounded_E =
union {
  object {Rounded_F}
  Capped_Cylinder (<.1,.1,0>,<.8,.1,0>,.1)
  }

// ----- Rounded_G -----
#declare Rounded_G =
union {
  object {Rounded_C}
  Rounded_Cylinder (<.6,.7,0>,<.9,.7,0>,.1)
  cylinder {<.9,.5,0>,<.9,.7,0>,.1}
  }
  
// ----- Rounded_H -----
#declare Rounded_H =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Rounded_Cylinder (<.7,.1,0>,<.7,1.4,0>,.1)
  cylinder {<.1,.8,0>,<.7,.8,0>,.1}
  }
    
// ----- Rounded_I -----
#declare Rounded_I =
union {
  Rounded_Cylinder (<.1,.1,0>,<.9,.1,0>,.1)
  Rounded_Cylinder (<.1,1.4,0>,<.9,1.4,0>,.1)
  cylinder {<.5,.1,0>,<.5,1.4,0>,.1}
  }

// ----- Rounded_J -----
#declare Rounded_J =
union {
  Half_Circle_Rounded (<.4,.4,0>,.3,.1,180)
  Rounded_Cylinder (<.7,.4,0>,<.7,1.4,0>,.1)
  }  
  
// ----- Rounded_K -----
#declare Rounded_K =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Rounded_Cylinder (<.1,.6,0>,<.9,1.4,0>,.1)
  Rounded_Cylinder (<.3,.8,0>,<.9,.1,0>,.1)
  }
  
// ----- Rounded_L -----
#declare Rounded_L =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Capped_Cylinder (<.1,.1,0>,<.8,.1,0>,.1)
  }
  
// ----- Rounded_M -----
#declare Rounded_M =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Capped_Cylinder (<.1,1.4,0>,<.5,.5,0>,.1)
  Capped_Cylinder (<.5,.5,0>,<.9,1.4,0>,.1)
  Capped_Cylinder (<.9,1.4,0>,<.9,.1,0>,.1)
  }

// ----- Rounded_N -----
#declare Rounded_N =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  cylinder {<.1,1.4,0>,<.9,.1,0>,.1}
  Rounded_Cylinder (<.9,.1,0>,<.9,1.4,0>,.1)
  }
  
// ----- Rounded_O -----
#declare Rounded_O =
union {
  object {Rounded_C}
  cylinder {<.9,.5,0>,<.9,1,0>,.1}
  }
  
// ----- Rounded_Q -----
#declare Rounded_Q =
union {
  object {Rounded_O}
  Rounded_Cylinder (<.9,.1,0>,<.6,.4,0>,.1)
  }
  
// ----- Rounded_R -----
#declare Rounded_R =
union {
  object {Rounded_P}
  Rounded_Cylinder (<.8,.1,0>,<.5,.8,0>,.1)
  }
  
// ----- Rounded_S -----
#declare Rounded_S =
union {
  Half_Circle_Rounded (<.4,1,0>,.3,.1,0)
  Half_Circle_Rounded (<.4,.4,0>,.3,.1,180)
  Quarter_Circle_Rounded (<.4,1,0>,.3,.1,180)
  Quarter_Circle_Rounded (<.4,.4,0>,.3,.1,0)
  }
  
// ----- Rounded_T -----
#declare Rounded_T =
union {
  Capped_Cylinder (<.5,1.4,0>,<.5,.1,0>,.1)
  Rounded_Cylinder (<.1,1.4,0>,<.9,1.4,0>,.1)
  }
  
// ----- Rounded_U -----
#declare Rounded_U =
union {
  object {Rounded_J}
  Capped_Cylinder (<.1,.4,0>,<.1,1.4,0>,.1)
  }
  
// ----- Rounded_V -----
#declare Rounded_V =
union {
  Rounded_Cylinder (<.1,1.4,0>,<.5,.1,0>,.1)
  Capped_Cylinder (<.5,.1,0>,<.9,1.4,0>,.1)
  }
  
// ----- Rounded_W -----
#declare Rounded_W =
union {
  Rounded_Cylinder (<.1,1.4,0>,<.4,.1,0>,.1)
  Capped_Cylinder (<.4,.1,0>,<.7,1.4,0>,.1)
  Capped_Cylinder (<.7,1.4,0>,<1,.1,0>,.1)
  Capped_Cylinder (<1,.1,0>,<1.3,1.4,0>,.1)
  }
   
// ----- Rounded_X -----
#declare Rounded_X =
union {
  Rounded_Cylinder (<.1,.1,0>,<.9,1.4,0>,.1)
  Rounded_Cylinder (<.9,.1,0>,<.1,1.4,0>,.1)
  }
  
// ----- Rounded_Y -----
#declare Rounded_Y =
union {
  Capped_Cylinder (<.5,.7,0>,<.5,.1,0>,.1)
  Rounded_Cylinder (<.1,1.4,0>,<.5,.7,0>,.1)
  Capped_Cylinder (<.5,.7,0>,<.9,1.4,0>,.1)
  }
  
// ----- Rounded_Z -----
#declare Rounded_Z =
union {
  Rounded_Cylinder (<.1,.1,0>,<.9,.1,0>,.1)
  Rounded_Cylinder (<.1,1.4,0>,<.9,1.4,0>,.1)
  cylinder {<.1,.1,0>,<.9,1.4,0>,.1}
  }
  
// ----- Rounded_o -----
#declare Rounded_o =
Torus (<.5,.5,0>,.4,.1)

// ----- Rounded_a -----
#declare Rounded_a =
union {
  object {Rounded_o}
  Rounded_Cylinder (<.9,.1,0>,<.9,.4,0>,.1)
  }
  
// ----- Rounded_b -----
#declare Rounded_b =
union {
  object {Rounded_o}
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  }
  
// ----- Rounded_c -----
#declare Rounded_c =
union {
  difference {
    torus {.4,.1 rotate <90,0,0>}
    box {<0,0,.11>,<1,1,-.11> rotate <0,0,-45>}
    }
  sphere {<.4,0,0>,.1 rotate <0,0,45>}
  sphere {<.4,0,0>,.1 rotate <0,0,-45>}
  translate <.5,.5,0>
  }
  
// ----- Rounded_d -----
#declare Rounded_d =
union {
  object {Rounded_o}
  Rounded_Cylinder (<.9,.1,0>,<.9,1.4,0>,.1)
  }
  
// ----- Rounded_e -----
#declare Rounded_e =
union {
  difference {
    torus {.4,.1 rotate <90,0,0>}
    #declare Count=10;
    #while (Count > -30)
      box {<0,0,-.11>,<.5,-.1,.11> rotate <0,0,Count>}
      #declare Count=Count-10;
    #end
    }
  Rounded_Cylinder (<-.39,.07,0>,<.39,.07,0>,.1)
  sphere {<.4,0,0>,.1 rotate <0,0,-31>}
  translate <.5,.5,0>
  }
  
    
// ----- Rounded_f -----
#declare Rounded_f =
union {
  Rounded_Cylinder (<.3,.1,0>,<.3,1.2,0>,.1)
  Rounded_Cylinder (<.1,.9,0>,<.5,.9,0>,.1)
  Half_Circle_Rounded (<.5,1.2,0>,.2,.1,0)
  }
  
// ----- Rounded_g -----
#declare Rounded_g =
union {
  torus {.4,.1 rotate <90,0,0> translate <.5,.5,0>}
  Rounded_Cylinder (<.9,0,0>,<.9,.9,0>,.1)
  Half_Circle_Rounded (<.5,0,0>,.4,.1,180)
  }
  
// ----- Rounded_h ----- .8
#declare Rounded_h = 
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  difference {
    torus {.3,.1 rotate <90,0,0>}
    box {<-.8,-.8,-.11>,<.8,0,.11>}
    translate <.4,.5,0>
    }
  sphere {<.7,.1,0>,.1}
  cylinder {<.7,.1,0>,<.7,.5,0>,.1}
}

// ----- Rounded_i -----
#declare Rounded_i =
union {
  Rounded_Cylinder (<.1,.9,0>,<.1,.1,0>,.1)
  sphere {<.1,1.2,0>,.1}
  }
  
// ----- Rounded_j -----
#declare Rounded_j =
union {
  Half_Circle_Rounded (<.4,0,0>,.3,.1,180)
  Rounded_Cylinder (<.7,0,0>,<.7,.9,0>,.1)
  }
  
// ----- Rounded_k -----
#declare Rounded_k =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  Rounded_Cylinder (<.1,.5,0>,<.7,.9,0>,.1)
  Rounded_Cylinder (<.2,.6,0>,<.7,.1,0>,.1)
  }
  
// ----- Rounded_l -----
#declare Rounded_l =
  Rounded_Cylinder (<.1,.1,0>,<.1,1.4,0>,.1)
  
// ----- Rounded_m -----
#declare Rounded_m =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,.9,0>,.1)
  Quarter_Circle_Rounded (<.3,.7,0>,.2,.1,0)
  Quarter_Circle_Rounded (<.3,.7,0>,.2,.1,90)
  Quarter_Circle_Rounded (<.7,.7,0>,.2,.1,0)
  Quarter_Circle_Rounded (<.7,.7,0>,.2,.1,90)
  Rounded_Cylinder (<.9,.1,0>,<.9,.7,0>,.1)
  Rounded_Cylinder (<.5,.1,0>,<.5,.7,0>,.1)
  }

// ----- Rounded_n -----
#declare Rounded_n =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,.9,0>,.1)
  Half_Circle_Rounded (<.4,.6,0>,.3,.1,0)
  Rounded_Cylinder (<.7,.1,0>,<.7,.6,0>,.1)
  }

// ----- Rounded_p -----
#declare Rounded_p =
union {
  Rounded_Cylinder (<.1,-.4,0>,<.1,.9,0>,.1)
  torus {.4,.1 rotate <90,0,0> translate <.5,.5,0>}
  }

// ----- Rounded_q -----
#declare Rounded_q =
union {
  object {Rounded_p rotate <0,180,0> translate <1,0,0>}
  Rounded_Cylinder (<.9,-.4,0>,<1.1,-.2,0>,.1)
  }

// ----- Rounded_r -----
#declare Rounded_r =
union {
  Rounded_Cylinder (<.1,.1,0>,<.1,.9,0>,.1)
  Quarter_Circle_Rounded (<.4,.6,0>,.3,.1,0)
  Quarter_Circle_Rounded (<.4,.6,0>,.3,.1,90)
  }

// ----- Rounded_s ----- .6
#declare Rounded_s =
union {  
  #declare Half =
    union {
      difference {
        torus {.2,.1 rotate <90,0,0>}
        box {<0,0,.11>,<1,-1,-.11>}
        }
    sphere {<.2,0,0>,.1}
    }
    object {Half translate <.3,.7,0>}
    object {Half rotate <180,180,0> translate <.3,.3,0>}
  }

// ----- Rounded_t -----
#declare Rounded_t =
union {
  Rounded_Cylinder (<.4,.1,0>,<.4,1.1,0>,.1)
  Rounded_Cylinder (<.1,.9,0>,<.7,.9,0>,.1)
  }

// ----- Rounded_u -----
#declare Rounded_u =
  object {Rounded_n rotate<0,0,180> translate<.8,1,0>}

// ----- Rounded_v -----
#declare Rounded_v =
union {
  Rounded_Cylinder (<.1,.9,0>,<.5,.1,0>,.1)
  Rounded_Cylinder (<.5,.1,0>,<.9,.9,0>,.1)
  }

// ----- Rounded_w -----
#declare Rounded_w =
union {
  Rounded_Cylinder (<.1,.9,0>,<.4,.1,0>,.1)
  Rounded_Cylinder (<.4,.1,0>,<.7,.9,0>,.1)
  Rounded_Cylinder (<.7,.9,0>,<1,.1,0>,.1)
  Rounded_Cylinder (<1,.1,0>,<1.3,.9,0>,.1)
  }

// ----- Rounded_x -----
#declare Rounded_x =
union {
  Rounded_Cylinder (<.1,.1,0>,<.7,.9,0>,.1)
  Rounded_Cylinder (<.1,.9,0>,<.7,.1,0>,.1)
  }

// ----- Rounded_y ----- .8
#declare Rounded_y =
union {
  Rounded_Cylinder (<.1,.9,0>,<.4,.1,0>,.1)
  Rounded_Cylinder (<.2,-.4,0>,<.7,.9,0>,.1)
  }

// ----- Rounded_z -----
#declare Rounded_z =
union {
  Rounded_Cylinder (<.1,.1,0>,<.9,.1,0>,.1)
  Rounded_Cylinder (<.1,.9,0>,<.9,.9,0>,.1)
  cylinder {<.1,.1,0>,<.9,.9,0>,.1}
  }
  
// ----- Rounded_Exc ------
#declare Rounded_Exc =
union {
  Rounded_Cylinder (<.1,.4,0>,<.1,1.4,0>,.1)
  sphere {<.1,.1,0>,.1}
  }

// ----- Rounded_DQuote -----
#declare Rounded_DQuote =
union {
  Rounded_Cylinder (<.1,.9,0>,<.1,1.4,0>,.1)
  Rounded_Cylinder (<.4,.9,0>,<.4,1.4,0>,.1)
  }

// ----- Rounded_Pound -----
#declare Rounded_Pound =
union {
  Rounded_Cylinder (<.2,.2,0>,<.4,1.3,0>,.1)
  Rounded_Cylinder (<.6,.2,0>,<.8,1.3,0>,.1)
  Rounded_Cylinder (<.1,.5,0>,<.8,.5,0>,.1)
  Rounded_Cylinder (<.2,1,0>,<.9,1,0>,.1)
  }                    
  
// ----- Rounded_Dollar -----
#declare Rounded_Dollar =
union {
  object{Rounded_S scale <.9,.9,1> translate <0,.1,0>}
  Rounded_Cylinder (<.35,.1,0>,<.35,1.4,0>,.1)
  }
  
// ----- Rounded_Percent -----
#declare Rounded_Percent =
union {
  Torus (<.3,1.2,0>,.2,.1)
  Torus (<.7,.3,0>,.2,.1)
  Rounded_Cylinder (<.2,.1,0>,<.8,1.4,0>,.1)
  }

// ----- Rounded_SQuote -----
#declare Rounded_SQuote =
  Rounded_Cylinder (<.1,.9,0>,<.1,1.4,0>,.1)
  
// ----- Rounded_OB -----
#declare Rounded_OP =
union {
  difference {
    Half_Circle_Rounded(<0,0,0>,1,.1,90)
    box {<0,0,-.2>,<1,1.6,.2> rotate <0,0,40>}
    box {<0,0,-.2>,<1,-1.6,.2> rotate <0,0,-40>}
    }
  sphere {<0,1,0>,.1 rotate <0,0,40>}
  sphere {<0,-1,0>,.1 rotate <0,0,-40>}
  translate <1.1,.75,0>
}

// ----- Rounded_CB -----
#declare Rounded_CP =
union {
  difference {
    Half_Circle_Rounded(<0,0,0>,1,.1,-90)
    box {<0,0,-.2>,<-1,1.6,.2> rotate <0,0,-40>}
    box {<0,0,-.2>,<-1,-1.6,.2> rotate <0,0,40>}
    }
  sphere {<0,1,0>,.1 rotate <0,0,-40>}
  sphere {<0,-1,0>,.1 rotate <0,0,40>}
  translate <-.55,.75,0>
}

// ----- Rounded_Star -----
#declare Rounded_Star =
union {
  Rounded_Cylinder(<.1,.227,0>,<.7,.573,0>,.1)
  Rounded_Cylinder(<.1,.573,0>,<.7,.227,0>,.1)
  Rounded_Cylinder(<.4,.1,0>,<.4,.7,0>,.1)
  translate <0,.3,0>
}

// ----- Rounded_Plus -----
#declare Rounded_Plus =
union {
  Rounded_Cylinder(<.4,.4,0>,<.4,1,0>,.1)
  Rounded_Cylinder(<.1,.7,0>,<.7,.7,0>,.1)
}

// ----- Rounded_Comma -----
#declare Rounded_Comma =
  Rounded_Cylinder(<.15,.1,0>,<.1,-.1,0>,.1)
  
// ----- Rounded_Minus -----
#declare Rounded_Minus =
  Rounded_Cylinder(<.1,.7,0>,<.7,.7,0>,.1)
  
// ----- Rounded_Period -----
#declare Rounded_Period =
  sphere{<.1,.1,0>,.1}
  
// ----- Rounded_FSlash -----
#declare Rounded_FSlash =
  Rounded_Cylinder(<.1,0,0>,<.4,1.5,0>,.1)

// ----- Rounded_0 -----
#declare Rounded_0 =
  object {Rounded_O}
  
// ----- Rounded_1 -----
#declare Rounded_1 =
union {
  Rounded_Cylinder (<.1,.1,0>,<.7,.1,0>,.1)
  Capped_Cylinder (<.4,.1,0>,<.4,1.4,0>,.1)
  Capped_Cylinder (<.4,1.4,0>,<.1,1.1,0>,.1)
}

// ----- Rounded_2 -----
#declare Rounded_2 =
union {
  Half_Circle_Rounded (<.45,1.05,0>,.35,.1,0)
  Uncapped_Eighth_Circle_Rounded (<.45,1.05,0>,.35,.1,-45)
  Uncapped_Eighth_Circle_Rounded (<.45,.1,0>,.35,.1,135)
  Rounded_Cylinder (<.697,.803,0>,<.203,.347,0>,.1)
  Rounded_Cylinder (<.1,.1,0>,<.8,.1,0>,.1)
  }
  
// ----- Rounded_3 -----
#declare Rounded_3 =
union {
  Half_Circle_Rounded (<.425,1.075,0>,.325,.1,0)
  Half_Circle_Rounded (<.425,.425,0>,.325,.1,180)
  Quarter_Circle_Rounded (<.425,1.075,0>,.325,.1,-90)
  Quarter_Circle_Rounded (<.425,.425,0>,.325,.1,0)
  Rounded_Cylinder (<.3,.75,0>,<.425,.75,0>,.1)
  }

// ----- Rounded_4 ----
#declare Rounded_4 =
union {
  Rounded_Cylinder (<.1,.6,0>,<.6,1.4,0>,.1)
  Rounded_Cylinder (<.1,.6,0>,<.8,.6,0>,.1)
  Rounded_Cylinder (<.6,.1,0>,<.6,1.4,0>,.1)
}

// ----- Rounded_5 -----
#declare Rounded_5 =
union {
  union {
    Half_Circle_Rounded (0,.4,.1,180)
    Quarter_Circle_Rounded (0,.4,.1,0)
    rotate <0,0,45>
    translate <.384,.5,0>
  }
  Rounded_Cylinder(<.1,.8,0>,<.1,1.4,0>,.1)
  Rounded_Cylinder(<.1,1.4,0>,<.784,1.4,0>,.1)
}                                             

// ----- Rounded_6 -----
#declare Rounded_6 =
union {
  Torus(<.45,.45,0>,.35,.1)
  Rounded_Cylinder(<.1,.45,0>,<.1,1.05,0>,.1)
  Half_Circle_Rounded(<.45,1.05,0>,.35,.1,0)
  
}

// ----- Rounded_7 -----
#declare Rounded_7 =
union {
  Rounded_Cylinder(<.2,.1,0>,<.7,1.4,0>,.1)
  Rounded_Cylinder(<.1,1.4,0>,<.7,1.4,0>,.1)
}

// ----- Rounded_8 -----
#declare Rounded_8 =
union {
  Torus(<.425,.425,0>,.325,.1)
  Torus(<.425,1.075,0>,.325,.1)
}

// ----- Rounded_9 -----
#declare Rounded_9 =
object {Rounded_6 rotate <0,0,180> translate <.9,1.5,0>}

// ----- Rounded_Colon -----
#declare Rounded_Colon =
union {
  sphere {<.15,.5,0>,.15}
  sphere {<.15,1,0>,.15}
  scale <1,1,(2/3)>
}

// ----- Rounded_Semicolon -----
#declare Rounded_Semicolon =
union {
  object {Rounded_Colon}
  Eighth_Circle_Rounded (<-.2,.5,0>,.4,.1,-45)
}

// ----- Rounded_LessThan -----
#declare Rounded_LessThan =
union {
  Rounded_Cylinder(<.1,.7,0>,<.8,1.1,0>,.1)
  Capped_Cylinder(<.1,.7,0>,<.8,.3,0>,.1)
}

// ----- Rounded_Equals -----
#declare Rounded_Equals =
union {
  Rounded_Cylinder(<.1,.5,0>,<.8,.5,0>,.1)
  Rounded_Cylinder(<.1,.8,0>,<.8,.8,0>,.1)
}

// ----- Rounded_GrThan -----
#declare Rounded_GrThan =
  object {Rounded_LessThan rotate <0,180,0> translate <.9,0,0>}
  
// ----- Rounded_Questionmark -----
#declare Rounded_Questionmark =
union {
  Half_Circle_Rounded(<.35,1.15,0>,.25,.1,0)
  Eighth_Circle_Rounded(<.15,1.15,0>,.45,.1,-45)
  Eighth_Circle_Rounded(<.8,.528,0>,.45,.1,135)
  Rounded_Cylinder(<.35,.528,0>,<.35,.4,0>,.1)
  sphere {<.35,.1,0>,.1}
}

// ----- Rounded_At -----
#declare Rounded_At =
union {
  Torus(<.6,.75,0>,.2,.1)
  Half_Circle_Rounded(<.7,.85,0>,.45,.1,-90)
  Half_Circle_Rounded(<.7,.7,0>,.6,.1,90)
  Rounded_Cylinder(<.7,.4,0>,<.85,.9,0>,.1)
  Eighth_Circle_Rounded(<.7,.7,0>,.6,.1,-90)
}

// ----- Rounded_OB -----
#declare Rounded_OB =
union {
  Rounded_Cylinder (<.1,-.2,0>,<.1,1.7,0>,.1)
  Rounded_Cylinder (<.1,-.2,0>,<.4,-.2,0>,.1)
  Rounded_Cylinder (<.1,1.7,0>,<.4,1.7,0>,.1)
}

// ----- Rounded_BSlash -----
#declare Rounded_BSlash =
  object {Rounded_FSlash rotate <0,180,0> translate <.5,0,0>}

// ----- Rounded_CB -----
#declare Rounded_CB =
  object {Rounded_OB rotate <0,180,0> translate <.4,0,0>}
  
// ----- Rounded_Carot -----
#declare Rounded_Carot =
union {
  Rounded_Cylinder(<.1,1,0>,<.4,1.4,0>,.1)
  Capped_Cylinder(<.4,1.4,0>,<.7,1,0>,.1)
}

// ----- Rounded_Underscore ----
#declare Rounded_Underscore =
  Rounded_Cylinder (<.1,.1,0>,<.8,.1,0>,.1)
  
// ----- Rounded_Thing -----
#declare Rounded_Thing =
  Rounded_Cylinder (<.1,1.4,0>,<.2,1.3,0>,.1)
  
// ----- Rounded_OCB -----
#declare Rounded_OCB =
union {
  Quarter_Circle_Rounded(<.5,1.2,0>,.2,.1,90)
  Quarter_Circle_Rounded(<.5,.3,0>,.2,.1,180)
  Quarter_Circle_Rounded(<.1,.95,0>,.2,.1,-90)
  Quarter_Circle_Rounded(<.1,.55,0>,.2,.1,0)
  cylinder{<.3,.3,0>,<.3,.55,0>.1}
  cylinder{<.3,.95,0>,<.3,1.2,0>,.1}
}



// ----- Rounded_CCB -----
#declare Rounded_CCB =  
  object{Rounded_OCB rotate <0,180,0> translate <.6,0,0>}
  
// ----- Rounded_Or -----
#declare Rounded_Or =
  Rounded_Cylinder (<.1,0,0>,<.1,1.5,0>,.1)
  
// ----- Rounded_Atilda -----
#declare Rounded_Atilda =
union {
  Eighth_Circle_Rounded(<.3,.5,0>,.5,.1,67.5)
  Eighth_Circle_Rounded(<.72,1.41,0>,.5,.1,-112.5)
}
